@@ -218,7 +218,9 @@ def getHubSiteConfig(hubname, sectionName, valueName):
 	try:
 		rv = hubzeroCMSConfig.get(sectionName, valueName)
 	except ConfigParser.NoOptionError:
-		rv = None
+		rv = ''
+        except ConfigParser.NoSectionError:
+                rv = ''
 	
 	return rv
 
