@@ -333,7 +333,7 @@ def addhubuser(hubname,
                gidNumber = 100, 
                uidNumber = -1, 
                gecos = "",
-               loginShell = "", 
+               loginShell = "/bin/bash", 
                skipCreateHome = False, 
                homeDir = "", 
                skipCreateGroup = False, 
@@ -581,4 +581,4 @@ def getLDAPMinUIDNumber(hubname = "", minUIDNumber=1, maxUIDNumber=1000):
 			rv = x
 			break
 
-	return rv
\ No newline at end of file
+	return rv
